import dbus


class Systemd:
    def __init__(self):
        self.bus = dbus.SessionBus()
        self.systemd = self.bus.get_object(
            "org.freedesktop.systemd1",
            "/org/freedesktop/systemd1",
        )
        self.manager = dbus.Interface(self.systemd, "org.freedesktop.systemd1.Manager")

    def service_start(self, service: str):
        return self.manager.StartUnit(f"{service}.service", "replace")

    def service_stop(self, service: str):
        return self.manager.StopUnit(f"{service}.service", "replace")

    def service_is_active(self, service: str):
        try:
            self.manager.GetUnit(service)
            return True
        except dbus.exceptions.DBusException:
            return False
